@@ -6,7 +6,7 @@ Implementation of the base Fitter, Source, Model and Parameter classes
 from __future__ import annotations
 
 import copy
-from typing import Tuple, Union
+from typing import Optional, Tuple, Union
 
 import lmfit as lm
 import numdifftools as nd
@@ -490,11 +490,11 @@ class Fitter:
             method: str = 'leastsq',
             mcmc_kwargs: dict = {},
             sampler_kwargs: dict = {},
-            filename: str = None,
+            filename: Optional[str] = None,
             steps: int = 1000,
             nwalkers: int = 50,
             scale_covar: bool = True,
-            iter_cb: callable = None) -> None:
+            iter_cb: Optional[callable] = None) -> None:
         """Perform a fit of the models (added to the sources) to the data in the sources.
         Models in the same source are summed together, models in different sources can be
         linked through their parameters.
@@ -576,7 +576,7 @@ class Fitter:
         self.updateInfo()
 
     def reportFit(self,
-                  modelpars: Union[lm.Parameters, None] = None,
+                  modelpars: Optional[lm.Parameters] = None,
                   show_correl: bool = False,
                   min_correl: float = 0.1,
                   sort_pars: Union[bool, callable] = False) -> str:
@@ -623,8 +623,8 @@ class Fitter:
             self.result.params[p].vary
         ] for p in self.result.params]
         columns = [
-            'Source', 'Model', 'Parameter', 'Value', 'Stderr',
-            'Boundary (min)', 'Boundary (max)', 'Expression', 'Vary'
+            'Source', 'Model', 'Parameter', 'Value', 'Stderr', 'Minimum',
+            'Maximum', 'Expression', 'Vary'
         ]
         df = pd.DataFrame(data=data, columns=columns)
         return df
@@ -638,8 +638,7 @@ class Fitter:
         pd.DataFrame"""
         columns = [
             'Source', 'Fitting method', 'Message', 'Function evaluations',
-            'Data points', 'Variables', 'Chi-square', 'Reduced chi-square',
-            'Akaike info criterium', 'Bayesian info criterium'
+            'Data points', 'Variables', 'Chisquare', 'Redchi', 'Aic', 'Bic'
         ]
         source = [name for (name, s) in self.sources]
         source = ', '.join(source)
@@ -651,7 +650,7 @@ class Fitter:
         df = pd.DataFrame(data=data, columns=columns)
         return df
 
-    def readWalk(self, filename: str, burnin: int = 0):
+    def readWalk(self, filename: str, burnin: Optional[int] = 0):
         """Read and process the h5 file containing the results of a random walk.
         The parameter values and uncertainties are extracted from the walk.
 
@@ -659,6 +658,8 @@ class Fitter:
         ----------
         filename : str
             Filename of the random walk results.
+        burnin: Optional[int]
+            Optional amount of steps to remove from the start, defaults to 0.
         """
         reader = SATLASHDFBackend(filename)
         # var_names = list(reader.labels)
@@ -705,7 +706,7 @@ class Fitter:
     def evaluateOverWalk(self,
                          filename: str,
                          burnin: int = 0,
-                         x: ArrayLike = None,
+                         x: Optional[ArrayLike] = None,
                          evals: int = 0) -> Tuple[list, list]:
         """The parameters saved in the h5 file are evaluated
         in the models a specific number of times. From these evaluations, the
@@ -785,28 +786,28 @@ class Fitter:
 
 
 class Source:
+    """Initializes a source of data
+
+    Parameters
+    ----------
+    x : ArrayLike
+        x values of the data
+    y : ArrayLike
+        y values of the data
+    yerr : Union[ArrayLike, callable]
+        The yerr of the data, either an array for fixed uncertainties
+        or a callable to be applied to the result of the models in the source.
+    name : str
+        The name given to the source. This must be a unique value!
+    xerr : ArrayLike, optional
+        If enlargement of the yerr with the xerr is required, supply this, by default None.
+    """
     def __init__(self,
                  x: ArrayLike,
                  y: ArrayLike,
                  yerr: Union[ArrayLike, callable],
                  name: str,
                  xerr: ArrayLike = None):
-        """Initializes a source of data
-
-        Parameters
-        ----------
-        x : ArrayLike
-            x values of the data
-        y : ArrayLike
-            y values of the data
-        yerr : Union[ArrayLike, callable]
-            The yerr of the data, either an array for fixed uncertainties
-            or a callable to be applied to the result of the models in the source.
-        name : str
-            The name given to the source. This must be a unique value!
-        xerr : ArrayLike, optional
-            If enlargement of the yerr with the xerr is required, supply this, by default None.
-        """
         super().__init__()
         self.x = x
         self.y = y
@@ -882,17 +883,17 @@ class Source:
 
 
 class Model:
-    def __init__(self, name: str, prefunc: callable = None):
-        """Base Model class
+    """Base Model class
 
-        Parameters
-        ----------
-        name : str
-            Name given to the model
-        prefunc : callable, optional
-            Transformation function to be applied to the
-            evaluation points before evaluating the model, by default None
-        """
+    Parameters
+    ----------
+    name : str
+        Name given to the model
+    prefunc : callable, optional
+        Transformation function to be applied to the
+        evaluation points before evaluating the model, by default None
+    """
+    def __init__(self, name: str, prefunc: Optional[callable] = None):
         super().__init__()
         self.name = name
         self.prefunc = prefunc
@@ -931,7 +932,18 @@ class Model:
         """
         self.prefunc = func
 
-    def f(self, x) -> float:
+    def f(self, x: ArrayLike) -> float:
+        """Evaluates the model in the given points.
+
+        Parameters
+        ----------
+        x : ArrayLike
+            Points in which the model has to be evaluated
+
+        Returns
+        -------
+        ArrayLike
+        """
         raise NotImplemented
 
 
